---
title: Spree 4.0.0
section: release_notes
order: 0
hidden: true
---

## Major/New Features

**Spree 4.0** requires **Rails 6.0** and **Ruby 2.5** (or higher).

### Rails 6.0 support

Spree 4.0 is fully compatible with [Rails 6.0](https://edgeguides.rubyonrails.org/6_0_release_notes.html)
and the new default [Zeitwerk code autoloader](https://weblog.rubyonrails.org/2019/2/22/zeitwerk-integration-in-rails-6-beta-2/).

### Storefront and Admin Panel moved to Bootstrap 4.2

We've migrated both the default Spree frontend and Admin Panel from Bootstrap 3 to Bootstrap 4.2. This update brings all of the new features and fixes introduced in [Bootstrap 4](https://blog.getbootstrap.com/2018/01/18/bootstrap-4/), [4.1](https://blog.getbootstrap.com/2018/04/09/bootstrap-4-1/) and [4.2](https://blog.getbootstrap.com/2018/12/21/bootstrap-4-2-1/). Accessibility and RWD were also improved in the process.

Besides the Spree Frontend and Admin Panel we've also upgraded all extensions that required fixes, that is:

- [Auth Devise](https://github.com/spree/spree_auth_devise)
- [I18n](https://github.com/spree-contrib/spree_i18n)
- [Multi Currency](https://github.com/spree-contrib/spree_multi_currency)
- [Analytics Trackers](https://github.com/spree-contrib/spree_analytics_trackers)
- [Digital](https://github.com/spree-contrib/spree_digital)
- [Social](https://github.com/spree-contrib/spree_social)
- [Editor](https://github.com/spree-contrib/spree_editor)
- [Recently Viewed](https://github.com/spree-contrib/spree_recently_viewed)
- [Related Products](https://github.com/spree-contrib/spree_related_products)
- [Static Content](https://github.com/spree-contrib/spree_static_content)
- [Email to friend](https://github.com/spree-contrib/spree_email_to_friend)
- [Volume Pricing](https://github.com/spree-contrib/spree_volume_pricing)
- [Braintree vzero](https://github.com/spree-contrib/spree_braintree_vzero)
- [Product Assembly](https://github.com/spree-contrib/spree-product-assembly)
- [Avatax Certified](https://github.com/spree-contrib/spree_avatax_certified)

If you use any of those extensions please update them along with the Spree update.

### Address Book support

Previously for multiple addresses support you had to use the [Spree Address Book](https://github.com/spree-contrib/spree_address_book) extension. We've decided that this was an inconsistency (user account already supported multiple credit cards) and moved this code into the core Spree and improved it.

Thanks to this signed in customers can manage multiple addresses in the Checkout and Account for both Shipping and Billing.

## Installation

### Add Spree gems to Gemfile

```ruby
gem 'spree', '~> 4.0'
gem 'spree_auth_devise', '~> 4.0'
gem 'spree_gateway', '~> 3.6'
```

### Run `bundle install`

### Use the install generators to set up Spree

```shell
rails g spree:install --user_class=Spree::User
rails g spree:auth:install
rails g spree_gateway:install
```

## Upgrade

[3.7 to 4.0 upgrade guide](/developer/upgrades/three-dot-seven-to-four-dot-oh.html)

## Noteworthy changes

Please review each of the noteworthy changes to ensure your customizations or extensions are not affected. If you are affected by a change, and have any suggestions please submit a PR to help the next person!

- Added presence and uniqueness validation for `Country#iso` and `Country#iso3` attributes

  [Spark Solutions](https://github.com/spree/spree/pull/9285)

- Added additional default zones (Asia, South America, Middle East)

  [lon10](https://github.com/spree/spree/pull/9430)

- Fixed potential XSS on Product Page

  [Atsushi Yamamoto](https://github.com/spree/spree/pull/9422)

- Added ability to set time parts of a promotion period

  [kirikiriyamama](https://github.com/spree/spree/pull/9450)

- Use API v2 for country state and zip in the Checkout address form

  [Matthew Kennedy](https://github.com/spree/spree/pull/9453)

- Added id to currency & security card divs in Admin Panel General Settings for easier override

  [Atsushi Yamamoto](https://github.com/spree/spree/pull/9421)

- Added `.cache` class in Admin Panel General Settings for easier override

  [Atsushi Yamamoto](https://github.com/spree/spree/pull/9419)

- Updated `factory_bot` to `5.0`

  [Spark Solutions](https://github.com/spree/spree/pull/9362)

- Updated `cancancan` to `3.0`

  [Spark Solutions](https://github.com/spree/spree/pull/9307)

- Updated `Capybara` to `3.24`

  [Thomas Walpole](https://github.com/spree/spree/pull/9424)

- Updated `rspec-rails` to `4.0`

  [Spark Solutions](https://github.com/spree/spree/commit/f1354c8e00ff69b5e01216b789c89aadb43f7ff6)

- Updated `ransack` to `3.2.0`

  [Spark Solutions](https://github.com/spree/spree/commit/fa4d4b31da543a1eb056098e13b4dcb269a2c511)

- Moved `ProductScopes` into a Concern

  [Spark Solutions](https://github.com/spree/spree/commit/1da20381892509df9a472f450300daf32241b89d)

- Deprecated `TestingSupport::ControllerRequests` methods like `spree_get`, `spree_post` etc

  [Spark Solutions](https://github.com/spree/spree/pull/9388)

- Removed deprecated `OrderContents`

  [Amalrik Maia](https://github.com/spree/spree/issues/8838)

- Removed deprecated `Address#iso_name` method

  [Spark Solutions](https://github.com/spree/spree/pull/9286/commits/17b629233be3f6d9facb8ecfb06a6f99a5ba3a4f)

- Removed deprecated `Adjustment#open` and `Adjustment#closed` scopes

  [Spark Solutions](https://github.com/spree/spree/pull/9286/commits/23568992c59f7249779037efb6ff0b6c6aea1b6a)

- Removed deprecated `BaseHelper#variant_options` method

  [Spark Solutions](https://github.com/spree/spree/pull/9286/commits/1483c27ba364a55067f464ec730e45153a8531a5)

- Removed deprecated `Order#set_currency` method

  [Spark Solutions](https://github.com/spree/spree/pull/9286/commits/e640891094e8f525243f1a507a231c2589c8c6dc)

- Removed deprecated `Order#register_line_item_comparison_hook` method

  [Spark Solutions](https://github.com/spree/spree/pull/9286/commits/81bbb534109225a9f7944f31d4507c733e5a6941)

- Removed deprecated `Order#guest_token` method

  [Spark Solutions](https://github.com/spree/spree/pull/9286/commits/103aa75139c9f3110a758e2cbcea2892d1519435)

- Removed deprecated `Address#same_as` method

  [Spark Solutions](https://github.com/spree/spree/pull/9286/commits/c7970720e531ac62b82f24280dc78748c04c0ec4)

- Removed deprecated hash case in `Order#create_line_items_from_params`

  [Spark Solutions](https://github.com/spree/spree/pull/9286/commits/963f6f432a4d6f6f07d174d3ed4e6cf8227458db)

- Removed deprecated `Order#line_item_options_match`

  [Spark Solutions](https://github.com/spree/spree/pull/9286/commits/2c3dcc72d594b891bb4749a36d30d8d49b675f4a)

- Removed deprecated `OrdersController#populate` and `OrdersController#populate_redirect` actions

  [Amalrik Maia](https://github.com/spree/spree/commit/d85b6137c5eb6346e171c8f5db7f8237cd7d08a5)

- Removed deprecated `RespondWith` module

  [Spark Solutions](https://github.com/spree/spree/pull/9379)

- Replaced `Spree::ProductScopes` with a concern

  [Spark Solutions](https://github.com/spree/spree/pull/9386)

- Replaced deprecated `chromedriver-helper` with `webdrivers` gem

  [Spark Solutions](https://github.com/spree/spree/pull/9381)

- Replaced `ControllerRequests#spree_` methods with standard get/post/put/etc

  [Spark Solutions](https://github.com/spree/spree/commit/123f4fd5fe366aae53b810323cd32f7c7ac651fb)

- Dropped `acts-as-taggable-on` dependency and tag support. This will be later moved into an extension after `acts-as-taggable-on` will fully support Rails 6.0

  [Spark Solutions](https://github.com/spree/spree/pull/9491)

- Dropped `Paperclip` support

  [Amalrik Maia](https://github.com/spree/spree/pull/9217)

- Dropped `deface` dependency

  [Spark Solutions](https://github.com/spree/spree/pull/9394)

- Dropped `versioncake` dependency

  [Spark Solutions](https://github.com/spree/spree/pull/9392)

- Dropped `rspec-collection_matchers` dependency

  [Spark Solutions](https://github.com/spree/spree/pull/9295)

- Dropped `rspec-its` dependency

  [Spark Solutions](https://github.com/spree/spree/pull/9292)

## Full Changelog

You can view the full changes using [Github Compare](https://github.com/spree/spree/compare/3-7-stable...master).
